@@ -1,13 +1,19 @@
-import re
-from typing import List, Optional, Type, get_args
+from __future__ import annotations
 
+import re
+from functools import cache
+from typing import Optional, get_args
+
+from maggma.utils import get_flat_models_from_model
 from monty.json import MSONable
 from pydantic import BaseModel
-from pydantic.schema import get_flat_models_from_model
-from pydantic.utils import lenient_issubclass
+from pydantic._internal._utils import lenient_issubclass
+from pydantic.fields import FieldInfo
+
+from mp_api.client.core.settings import MAPIClientSettings
 
 
-def validate_ids(id_list: List[str]):
+def validate_ids(id_list: list[str]):
     """Function to validate material and task IDs.
 
     Args:
@@ -19,6 +25,12 @@ def validate_ids(id_list: List[str]):
     Returns:
         id_list: Returns original ID list if everything is formatted correctly.
     """
+    if len(id_list) > MAPIClientSettings().MAX_LIST_LENGTH:
+        raise ValueError(
+            "List of material/molecule IDs provided is too long. Consider removing the ID filter to automatically pull"
+            " data for all IDs and filter locally."
+        )
+
     pattern = "(mp|mvc|mol|mpcule)-.*"
 
     for entry in id_list:
@@ -28,9 +40,10 @@ def validate_ids(id_list: List[str]):
     return id_list
 
 
+@cache
 def api_sanitize(
-    pydantic_model: Type[BaseModel],
-    fields_to_leave: Optional[List[str]] = None,
+    pydantic_model: BaseModel,
+    fields_to_leave: list[str] | None = None,
     allow_dict_msonable=False,
 ):
     """Function to clean up pydantic models for the API by:
@@ -40,13 +53,17 @@ def api_sanitize(
     WARNING: This works in place, so it mutates the model and all sub-models
 
     Args:
-        fields_to_leave: list of strings for model fields as "model__name__.field"
+        pydantic_model (BaseModel): Pydantic model to alter
+        fields_to_leave (list[str] | None): list of strings for model fields as "model__name__.field".
+            Defaults to None.
+        allow_dict_msonable (bool): Whether to allow dictionaries in place of MSONable quantities.
+            Defaults to False
     """
     models = [
         model
         for model in get_flat_models_from_model(pydantic_model)
         if issubclass(model, BaseModel)
-    ]  # type: List[Type[BaseModel]]
+    ]  # type: list[BaseModel]
 
     fields_to_leave = fields_to_leave or []
     fields_tuples = [f.split(".") for f in fields_to_leave]
@@ -54,33 +71,35 @@ def api_sanitize(
 
     for model in models:
         model_fields_to_leave = {f[1] for f in fields_tuples if model.__name__ == f[0]}
-        for name, field in model.__fields__.items():
-            field_type = field.type_
-
-            if name not in model_fields_to_leave:
-                field.required = False
-                field.default = None
-                field.default_factory = None
-                field.allow_none = True
-                field.field_info.default = None
-                field.field_info.default_factory = None
+        for name in model.model_fields:
+            field = model.model_fields[name]
+            field_json_extra = field.json_schema_extra
+            field_type = field.annotation
 
             if field_type is not None and allow_dict_msonable:
                 if lenient_issubclass(field_type, MSONable):
-                    field.type_ = allow_msonable_dict(field_type)
+                    field_type = allow_msonable_dict(field_type)
                 else:
                     for sub_type in get_args(field_type):
                         if lenient_issubclass(sub_type, MSONable):
                             allow_msonable_dict(sub_type)
-                field.populate_validators()
+
+            if name not in model_fields_to_leave:
+                new_field = FieldInfo.from_annotated_attribute(
+                    Optional[field_type], None
+                )
+                new_field.json_schema_extra = field_json_extra or {}
+                model.model_fields[name] = new_field
+
+        model.model_rebuild(force=True)
 
     return pydantic_model
 
 
-def allow_msonable_dict(monty_cls: Type[MSONable]):
+def allow_msonable_dict(monty_cls: type[MSONable]):
     """Patch Monty to allow for dict values for MSONable."""
 
-    def validate_monty(cls, v):
+    def validate_monty(cls, v, _):
         """Stub validator for MSONable as a dictionary only."""
         if isinstance(v, cls):
             return v
@@ -102,6 +121,6 @@ def allow_msonable_dict(monty_cls: Type[MSONable]):
         else:
             raise ValueError(f"Must provide {cls.__name__} or MSONable dictionary")
 
-    monty_cls.validate_monty = classmethod(validate_monty)
+    monty_cls.validate_monty_v2 = classmethod(validate_monty)
 
     return monty_cls
