@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from .absorption import AbsorptionRester
 from .bonds import BondsRester
 from .chemenv import ChemenvRester
@@ -11,10 +13,8 @@ from .electronic_structure import (
     ElectronicStructureRester,
 )
 from .eos import EOSRester
-from .fermi import FermiRester
-from .grain_boundary import GrainBoundaryRester
+from .grain_boundaries import GrainBoundaryRester
 from .magnetism import MagnetismRester
-from .materials import MaterialsRester
 from .oxidation_states import OxidationStatesRester
 from .phonon import PhononRester
 from .piezo import PiezoRester
