@@ -1,12 +1,15 @@
+from __future__ import annotations
+
+import json
 import warnings
 from collections import defaultdict
-from typing import List, Optional, Tuple, Union
 
 from emmet.core.electronic_structure import (
     BSPathType,
     DOSProjectionType,
     ElectronicStructureDoc,
 )
+from monty.json import MontyDecoder
 from pymatgen.analysis.magnetism.analyzer import Ordering
 from pymatgen.core.periodic_table import Element
 from pymatgen.electronic_structure.core import OrbitalType, Spin
@@ -33,22 +36,21 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
 
     def search(
         self,
-        material_ids: Optional[Union[str, List[str]]] = None,
-        band_gap: Optional[Tuple[float, float]] = None,
-        chemsys: Optional[Union[str, List[str]]] = None,
-        efermi: Optional[Tuple[float, float]] = None,
-        elements: Optional[List[str]] = None,
-        exclude_elements: Optional[List[str]] = None,
-        formula: Optional[Union[str, List[str]]] = None,
-        is_gap_direct: bool = None,
-        is_metal: bool = None,
-        magnetic_ordering: Optional[Ordering] = None,
-        num_elements: Optional[Tuple[int, int]] = None,
-        sort_fields: Optional[List[str]] = None,
-        num_chunks: Optional[int] = None,
+        material_ids: str | list[str] | None = None,
+        band_gap: tuple[float, float] | None = None,
+        chemsys: str | list[str] | None = None,
+        efermi: tuple[float, float] | None = None,
+        elements: list[str] | None = None,
+        exclude_elements: list[str] | None = None,
+        formula: str | list[str] | None = None,
+        is_gap_direct: bool | None = None,
+        is_metal: bool | None = None,
+        magnetic_ordering: Ordering | None = None,
+        num_elements: tuple[int, int] | None = None,
+        num_chunks: int | None = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
-        fields: Optional[List[str]] = None,
+        fields: list[str] | None = None,
     ):
         """Query electronic structure docs using a variety of search criteria.
 
@@ -68,7 +70,6 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
             is_metal (bool): Whether the material is considered a metal.
             magnetic_ordering (Ordering): Magnetic ordering of the material.
             num_elements (Tuple[int,int]): Minimum and maximum number of elements to consider.
-            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -128,11 +129,6 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
         if is_metal is not None:
             query_params.update({"is_metal": is_metal})
 
-        if sort_fields:
-            query_params.update(
-                {"_sort_fields": ",".join([s.strip() for s in sort_fields])}
-            )
-
         query_params = {
             entry: query_params[entry]
             for entry in query_params
@@ -165,17 +161,16 @@ class BandStructureRester(BaseRester):
 
     def search(
         self,
-        band_gap: Optional[Tuple[float, float]] = None,
-        efermi: Optional[Tuple[float, float]] = None,
-        is_gap_direct: bool = None,
-        is_metal: bool = None,
-        magnetic_ordering: Optional[Ordering] = None,
+        band_gap: tuple[float, float] | None = None,
+        efermi: tuple[float, float] | None = None,
+        is_gap_direct: bool | None = None,
+        is_metal: bool | None = None,
+        magnetic_ordering: Ordering | None = None,
         path_type: BSPathType = BSPathType.setyawan_curtarolo,
-        sort_fields: Optional[List[str]] = None,
-        num_chunks: Optional[int] = None,
+        num_chunks: int | None = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
-        fields: Optional[List[str]] = None,
+        fields: list[str] | None = None,
     ):
         """Query band structure summary data in electronic structure docs using a variety of search criteria.
 
@@ -186,7 +181,6 @@ class BandStructureRester(BaseRester):
             is_metal (bool): Whether the material is considered a metal.
             magnetic_ordering (Ordering): Magnetic ordering of the material.
             path_type (BSPathType): k-path selection convention for the band structure.
-            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -217,11 +211,6 @@ class BandStructureRester(BaseRester):
         if is_metal is not None:
             query_params.update({"is_metal": is_metal})
 
-        if sort_fields:
-            query_params.update(
-                {"_sort_fields": ",".join([s.strip() for s in sort_fields])}
-            )
-
         query_params = {
             entry: query_params[entry]
             for entry in query_params
@@ -245,13 +234,15 @@ class BandStructureRester(BaseRester):
         Returns:
             bandstructure (BandStructure): BandStructure or BandStructureSymmLine object
         """
-
+        decoder = MontyDecoder().decode if self.monty_decode else json.loads
         result = self._query_open_data(
-            bucket="materialsproject-parsed", prefix="bandstructures", key=task_id
-        )
+            bucket="materialsproject-parsed",
+            key=f"bandstructures/{task_id}.json.gz",
+            decoder=decoder,
+        )[0]
 
-        if result.get("data", None) is not None:
-            return result["data"]
+        if result:
+            return result[0]["data"]
         else:
             raise MPRestError("No object found")
 
@@ -264,7 +255,7 @@ class BandStructureRester(BaseRester):
         """Get the band structure pymatgen object associated with a Materials Project ID.
 
         Arguments:
-            materials_id (str): Materials Project ID for a material
+            material_id (str): Materials Project ID for a material
             path_type (BSPathType): k-point path selection convention
             line_mode (bool): Whether to return data for a line-mode calculation
 
@@ -272,20 +263,37 @@ class BandStructureRester(BaseRester):
             bandstructure (Union[BandStructure, BandStructureSymmLine]): BandStructure or BandStructureSymmLine object
         """
         es_rester = ElectronicStructureRester(
-            endpoint=self.base_endpoint, api_key=self.api_key
+            api_key=self.api_key,
+            endpoint=self.base_endpoint,
+            include_user_agent=self.include_user_agent,
+            session=self.session,
+            monty_decode=self.monty_decode,
+            use_document_model=self.use_document_model,
+            headers=self.headers,
+            mute_progress_bars=self.mute_progress_bars,
         )
 
         if line_mode:
-            bs_data = es_rester.get_data_by_id(
-                document_id=material_id, fields=["bandstructure"]
-            ).bandstructure
+            bs_doc = es_rester.search(
+                material_ids=material_id, fields=["bandstructure"]
+            )
+            if not bs_doc:
+                raise MPRestError("No electronic structure data found.")
+
+            bs_data = (
+                bs_doc[0].bandstructure  # type: ignore
+                if self.use_document_model
+                else bs_doc[0]["bandstructure"]  # type: ignore
+            )
 
             if bs_data is None:
                 raise MPRestError(
                     f"No {path_type.value} band structure data found for {material_id}"
                 )
             else:
-                bs_data = bs_data.dict()
+                bs_data: dict = (
+                    bs_data.model_dump() if self.use_document_model else bs_data  # type: ignore
+                )
 
             if bs_data.get(path_type.value, None):
                 bs_task_id = bs_data[path_type.value]["task_id"]
@@ -294,16 +302,25 @@ class BandStructureRester(BaseRester):
                     f"No {path_type.value} band structure data found for {material_id}"
                 )
         else:
-            bs_data = es_rester.get_data_by_id(
-                document_id=material_id, fields=["dos"]
-            ).dos
+            bs_doc = es_rester.search(material_ids=material_id, fields=["dos"])
+
+            if not bs_doc:
+                raise MPRestError("No electronic structure data found.")
+
+            bs_data = (
+                bs_doc[0].dos  # type: ignore
+                if self.use_document_model
+                else bs_doc[0]["dos"]  # type: ignore
+            )
 
             if bs_data is None:
                 raise MPRestError(
                     f"No uniform band structure data found for {material_id}"
                 )
             else:
-                bs_data = bs_data.dict()
+                bs_data: dict = (
+                    bs_data.model_dump() if self.use_document_model else bs_data  # type: ignore
+                )
 
             if bs_data.get("total", None):
                 bs_task_id = bs_data["total"]["1"]["task_id"]
@@ -337,18 +354,17 @@ class DosRester(BaseRester):
 
     def search(
         self,
-        band_gap: Optional[Tuple[float, float]] = None,
-        efermi: Optional[Tuple[float, float]] = None,
-        element: Optional[Element] = None,
-        magnetic_ordering: Optional[Ordering] = None,
-        orbital: Optional[OrbitalType] = None,
+        band_gap: tuple[float, float] | None = None,
+        efermi: tuple[float, float] | None = None,
+        element: Element | None = None,
+        magnetic_ordering: Ordering | None = None,
+        orbital: OrbitalType | None = None,
         projection_type: DOSProjectionType = DOSProjectionType.total,
         spin: Spin = Spin.up,
-        sort_fields: Optional[List[str]] = None,
-        num_chunks: Optional[int] = None,
+        num_chunks: int | None = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
-        fields: Optional[List[str]] = None,
+        fields: list[str] | None = None,
     ):
         """Query density of states summary data in electronic structure docs using a variety of search criteria.
 
@@ -360,7 +376,6 @@ class DosRester(BaseRester):
             orbital (OrbitalType): Orbital for orbital-projected dos data.
             projection_type (DOSProjectionType): Projection type of dos data. Default is the total dos.
             spin (Spin): Spin channel of dos data. If non spin-polarized data is stored in Spin.up
-            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -392,11 +407,6 @@ class DosRester(BaseRester):
         if magnetic_ordering:
             query_params.update({"magnetic_ordering": magnetic_ordering.value})
 
-        if sort_fields:
-            query_params.update(
-                {"_sort_fields": ",".join([s.strip() for s in sort_fields])}
-            )
-
         query_params = {
             entry: query_params[entry]
             for entry in query_params
@@ -420,12 +430,15 @@ class DosRester(BaseRester):
         Returns:
             bandstructure (CompleteDos): CompleteDos object
         """
+        decoder = MontyDecoder().decode if self.monty_decode else json.loads
         result = self._query_open_data(
-            bucket="materialsproject-parsed", prefix="dos", key=task_id
-        )
+            bucket="materialsproject-parsed",
+            key=f"dos/{task_id}.json.gz",
+            decoder=decoder,
+        )[0]
 
-        if result.get("data", None) is not None:
-            return result["data"]
+        if result:
+            return result[0]["data"]  # type: ignore
         else:
             raise MPRestError("No object found")
 
@@ -433,18 +446,29 @@ class DosRester(BaseRester):
         """Get the complete density of states pymatgen object associated with a Materials Project ID.
 
         Arguments:
-            materials_id (str): Materials Project ID for a material
+            material_id (str): Materials Project ID for a material
 
         Returns:
             dos (CompleteDos): CompleteDos object
         """
         es_rester = ElectronicStructureRester(
-            endpoint=self.base_endpoint, api_key=self.api_key
+            api_key=self.api_key,
+            endpoint=self.base_endpoint,
+            include_user_agent=self.include_user_agent,
+            session=self.session,
+            monty_decode=self.monty_decode,
+            use_document_model=self.use_document_model,
+            headers=self.headers,
+            mute_progress_bars=self.mute_progress_bars,
         )
 
-        dos_data = es_rester.get_data_by_id(
-            document_id=material_id, fields=["dos"]
-        ).dict()
+        dos_doc = es_rester.search(material_ids=material_id, fields=["dos"])
+        if not dos_doc:
+            return None
+
+        dos_data: dict = (
+            dos_doc[0].model_dump() if self.use_document_model else dos_doc[0]  # type: ignore
+        )
 
         if dos_data["dos"]:
             dos_task_id = dos_data["dos"]["total"]["1"]["task_id"]
