@@ -1,4 +1,4 @@
-from typing import List, Optional, Union
+from __future__ import annotations
 
 from emmet.core.molecules.vibration import VibrationDoc
 from emmet.core.mpid import MPculeID
@@ -13,25 +13,23 @@ class MoleculesVibrationRester(BaseRester[VibrationDoc]):
 
     def search(
         self,
-        molecule_ids: Optional[Union[MPculeID, List[MPculeID]]] = None,
-        property_ids: Optional[Union[str, List[str]]] = None,
-        charge: Optional[int] = None,
-        spin_multiplicity: Optional[int] = None,
-        level_of_theory: Optional[str] = None,
-        solvent: Optional[str] = None,
-        lot_solvent: Optional[str] = None,
-        formula: Optional[Union[str, List[str]]] = None,
-        elements: Optional[List[str]] = None,
-        exclude_elements: Optional[List[str]] = None,
-        chemsys: Optional[Union[str, List[str]]] = None,
-        num_chunks: Optional[int] = None,
-        sort_fields: Optional[List[str]] = None,
+        molecule_ids: MPculeID | list[MPculeID] | None = None,
+        property_ids: str | list[str] | None = None,
+        charge: int | None = None,
+        spin_multiplicity: int | None = None,
+        level_of_theory: str | None = None,
+        solvent: str | None = None,
+        lot_solvent: str | None = None,
+        formula: str | list[str] | None = None,
+        elements: list[str] | None = None,
+        exclude_elements: list[str] | None = None,
+        chemsys: str | list[str] | None = None,
+        num_chunks: int | None = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
-        fields: Optional[List[str]] = None,
+        fields: list[str] | None = None,
     ):
-        """
-        Query molecules vibration docs using a variety of search criteria.
+        """Query molecules vibration docs using a variety of search criteria.
 
         Arguments:
             molecule_ids (MPculeID, List[MPculeID]): List of Materials Project Molecule IDs (MPculeIDs) to return data
@@ -66,9 +64,8 @@ class MoleculesVibrationRester(BaseRester[VibrationDoc]):
             elements (List[str]): A list of elements.
             exclude_elements (List(str)): List of elements to exclude.
             chemsys (str, List[str]): A chemical system, list of chemical systems
-                (e.g., Li-C-O, [C-O-H-N, Li-N]), or single formula (e.g., C2 H4).
+                (e.g., Li-C-O, [C-O-H-N, Li-N]).
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
-            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
             fields (List[str]): List of fields in MoleculeDoc to return data for.
@@ -78,7 +75,6 @@ class MoleculesVibrationRester(BaseRester[VibrationDoc]):
         Returns:
             ([VibrationDoc]) List of molecule vibration documents
         """
-
         query_params = {}  # type: dict
 
         if molecule_ids:
